==> kubernetes-model-apiextensions-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrArrayFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface JSONSchemaPropsOrArrayFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<A>> extends Fluent<A> {


    public A addToJSONSchemas(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public A setToJSONSchemas(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public A addToJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... items);
    public A addAllToJSONSchemas(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> items);
    public A removeFromJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... items);
    public A removeAllFromJSONSchemas(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> items);
    public A removeMatchingFromJSONSchemas(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildJSONSchemas instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> getJSONSchemas();
    public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> buildJSONSchemas();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildJSONSchema(int index);
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildFirstJSONSchema();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildLastJSONSchema();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildMatchingJSONSchema(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
    public Boolean hasMatchingJSONSchema(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
    public A withJSONSchemas(List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> jSONSchemas);
    public A withJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... jSONSchemas);
    public Boolean hasJSONSchemas();
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> addNewJSONSchema();
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> addNewJSONSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> setNewJSONSchemaLike(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editJSONSchema(int index);
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editFirstJSONSchema();
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editLastJSONSchema();
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editMatchingJSONSchema(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSchema instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps getSchema();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildSchema();
    public A withSchema(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps schema);
    public Boolean hasSchema();
    public JSONSchemaPropsOrArrayFluent.SchemaNested<A> withNewSchema();
    public JSONSchemaPropsOrArrayFluent.SchemaNested<A> withNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public JSONSchemaPropsOrArrayFluent.SchemaNested<A> editSchema();
    public JSONSchemaPropsOrArrayFluent.SchemaNested<A> editOrNewSchema();
    public JSONSchemaPropsOrArrayFluent.SchemaNested<A> editOrNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public interface JSONSchemasNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluent<JSONSchemaPropsOrArrayFluent.JSONSchemasNested<N>> {

        public N and();
        public N endJSONSchema();    }


    public interface SchemaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluent<JSONSchemaPropsOrArrayFluent.SchemaNested<N>> {

        public N and();
        public N endSchema();    }


}

==> kubernetes-model-apiextensions-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrArrayFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface JSONSchemaPropsOrArrayFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<A>> extends Fluent<A> {


    public A addToJSONSchemas(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public A setToJSONSchemas(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public A addToJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... items);
    public A addAllToJSONSchemas(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> items);
    public A removeFromJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... items);
    public A removeAllFromJSONSchemas(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> items);
    public A removeMatchingFromJSONSchemas(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildJSONSchemas instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> getJSONSchemas();
    public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> buildJSONSchemas();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildJSONSchema(int index);
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildFirstJSONSchema();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildLastJSONSchema();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildMatchingJSONSchema(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
    public Boolean hasMatchingJSONSchema(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
    public A withJSONSchemas(List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps> jSONSchemas);
    public A withJSONSchemas(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps... jSONSchemas);
    public Boolean hasJSONSchemas();
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> addNewJSONSchema();
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> addNewJSONSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> setNewJSONSchemaLike(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editJSONSchema(int index);
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editFirstJSONSchema();
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editLastJSONSchema();
    public JSONSchemaPropsOrArrayFluent.JSONSchemasNested<A> editMatchingJSONSchema(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSchema instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps getSchema();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps buildSchema();
    public A withSchema(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps schema);
    public Boolean hasSchema();
    public JSONSchemaPropsOrArrayFluent.SchemaNested<A> withNewSchema();
    public JSONSchemaPropsOrArrayFluent.SchemaNested<A> withNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public JSONSchemaPropsOrArrayFluent.SchemaNested<A> editSchema();
    public JSONSchemaPropsOrArrayFluent.SchemaNested<A> editOrNewSchema();
    public JSONSchemaPropsOrArrayFluent.SchemaNested<A> editOrNewSchemaLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaProps item);
    public interface JSONSchemasNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluent<JSONSchemaPropsOrArrayFluent.JSONSchemasNested<N>> {

            public N and();
            public N endJSONSchema();    }


    public interface SchemaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsFluent<JSONSchemaPropsOrArrayFluent.SchemaNested<N>> {

            public N and();
            public N endSchema();    }


}
